{% load pagination_tags %}
{% spaceless %}
{% if current_page.publisher_is_draft or instance.check_publication is True %}
  <div class="organization-list__content">
    {% for organization in organizations %}
      {% include "courses/cms/fragment_organization_glimpse.html" with variant=instance.variant %}
    {% endfor %}
  </div>
{% endif %}
{% endspaceless %}
